<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Activar o plugin',
	'affichage' => 'Mostrar',
	'aide_non_disponible' => 'Esta parte da ajuda online ainda não está disponível neste idioma.',
	'annuler_recherche' => 'Cancelar a pesquisa',
	'auteur' => 'Autor :',
	'avis_acces_interdit' => 'Accesso interdito. ',
	'avis_acces_interdit_prive' => 'Não está autorizado a aceder à página <b>@exec@</b>.',
	'avis_article_modifie' => 'Atenção, @nom_auteur_modif@  trabalhou neste artigo há @date_diff@ minutes',
	'avis_aucun_resultat' => 'Sem resultados. ',
	'avis_base_inaccessible' => 'Impossível conectar-se à base de dados @base@.',
	'avis_chemin_invalide_1' => 'O caminho que escolheu ',
	'avis_chemin_invalide_2' => 'não parece ser válido. Por favor regresse à página anterior e verifique as informações fornecidas. ',
	'avis_connexion_echec_1' => 'A ligação ao servidor SQL falhou.',
	'avis_connexion_echec_2' => 'Volte à página anterior e verifique as informações que forneceu. ',
	'avis_connexion_echec_3' => '<b>N.B.</b> Em diversos servidores, precisa <b>solicitar</b> a activação do seu acesso à base de dados SQL antes de poder utilizá-la. Se não consegue ligar-se à sua base de dados, verifique se efectuou esse pedido.',
	'avis_connexion_erreur_creer_base' => 'Não foi possível criar a base de dados.',
	'avis_connexion_erreur_nom_base' => 'O nome da base de dados só pode conter letras, números e hífen.',
	'avis_connexion_ldap_echec_1' => 'A ligação ao servidor LDAP falhou.',
	'avis_connexion_ldap_echec_2' => 'Volte à página anterior e verifique as informações que forneceu ',
	'avis_connexion_ldap_echec_3' => 'Alternativamente, não utilize o suporte LDAP para importar utilizadores.',
	'avis_deplacement_rubrique' => 'Atenção ! Esta rubrica contém @contient_breves@ informação@scb@ : se a deslocar, por favor confirme-o nesta caixa.',
	'avis_erreur_connexion_mysql' => 'Erro de ligação SQL',
	'avis_espace_interdit' => '<b>Espaço interdito</b><p>SPIP já está instalado.',
	'avis_lecture_noms_bases_1' => 'O programa de instalação não conseguiu ler os nomes das bases de dados instaladas. ',
	'avis_lecture_noms_bases_2' => 'Ou nenhuma base de dados está disponível, ou a função que permite listá-las foi desactivada
por razões de segurança (o que é o caso em muitos serviços de hospedagem).  ',
	'avis_lecture_noms_bases_3' => 'Na segunda alternativa, é provável que uma base tendo o  seu nome de login seja utilizável :',
	'avis_non_acces_page' => 'Não tem acesso a esta página. ',
	'avis_operation_echec' => 'A operação falhou. ',
	'avis_operation_impossible' => 'Operação impossivel',
	'avis_suppression_base' => 'Atenção, a supressão dos dados é irreversível',

	// B
	'bouton_acces_ldap' => 'Acrescentar o acesso a LDAP >>',
	'bouton_ajouter' => 'Acrescentar ',
	'bouton_annuler' => 'Cancelar',
	'bouton_cache_activer' => 'Reactivar a cache',
	'bouton_cache_desactiver' => 'Desactivar temporariamente a cache',
	'bouton_demande_publication' => 'Pedir a publicação deste artigo ',
	'bouton_desactive_tout' => 'Desactivar tudo',
	'bouton_desinstaller' => 'Desinstalar',
	'bouton_effacer_tout' => 'Apagar TUDO',
	'bouton_envoyer_message' => 'Mensagem definitiva: enviar',
	'bouton_fermer' => 'Fechar',
	'bouton_mettre_a_jour_base' => 'Actualizar a base de dados',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Exibir',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparecer na lista dos redactores ligados',
	'bouton_radio_envoi_annonces_adresse' => 'Enviar os anúncios para o endereço:',
	'bouton_radio_envoi_liste_nouveautes' => 'Enviar a lista das novidades',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Não aparecer na lista dos redactores online',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Não enviar anúncios editoriais',
	'bouton_redirection' => 'REDIRECCIONAR',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Repor para valores padrão',
	'bouton_relancer_inscription' => 'Relançar o registo',
	'bouton_relancer_inscriptions' => 'Relançar os registos',
	'bouton_relancer_installation' => 'Recomeçar a instalação',
	'bouton_reset_password' => 'Gerar uma nova senha e enviá-la por e-mail',
	'bouton_suivant' => 'Seguinte',
	'bouton_tenter_recuperation' => 'Tentar uma reparação',
	'bouton_test_proxy' => 'Testar o proxy',
	'bouton_vider_cache' => 'Esvaziar a cache',

	// C
	'cache_modifiable_webmestre' => 'Este parâmetro é modificável pelo webmaster do site.',
	'calendrier_synchro' => 'Se utilizar um software de agenda compatível <b>iCal</b>, pode sincronizá-lo com as informações deste sítio.',
	'config_activer_champs' => 'Activar os campos seguintes',
	'config_choix_base_sup' => 'Escolher uma base de dados neste servidor',
	'config_erreur_base_sup' => 'SPIP não tem acesso à lista de bases de dados disponíveis',
	'config_info_base_sup' => 'Se precisar de consultar outras bases de dados usando SPIP, quer seja neste servidor SQL ou noutro, use este formulário para as declarar. Se deixar alguns campos por preencher, os identificadores de conexão à base de dados principal serão usados.',
	'config_info_base_sup_disponibles' => 'Bases de dados adicionais que se podem consultar:',
	'config_info_enregistree' => 'A nova configuração foi guardada',
	'config_info_logos' => 'Cada elemento do site pode ter o seu próprio logo, assim como um «mouseover»',
	'config_info_logos_utiliser' => 'Utilizar os logos',
	'config_info_logos_utiliser_non' => 'Não utilizar os logos',
	'config_info_logos_utiliser_survol' => 'Usar os logos de "mouseover"',
	'config_info_logos_utiliser_survol_non' => 'Não usar os logos de "mouseover"',
	'config_info_redirection' => 'Activando esta opção, pode criar artigos virtuais, que são referências simples a artigos publicados noutros sítios, não necessariamente usando SPIP.',
	'config_redirection' => 'Artigos virtuais',
	'config_titre_base_sup' => 'Declaração de uma base de dados suplementar',
	'config_titre_base_sup_choix' => 'Escolher uma base de dados suplementar',
	'connexion_ldap' => 'Conexão:',
	'creer_et_associer_un_auteur' => 'Criar e associar um autor',

	// D
	'date_mot_heures' => 'horas',

	// E
	'ecran_connexion_couleur_principale' => 'Cor principal',
	'ecran_connexion_image_fond' => 'Imagem de fundo',
	'ecran_connexion_image_fond_explication' => 'Usar uma imagem (formato JPEG, 1920x1080 pixels)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Reverter para a cor padrão',
	'ecran_connexion_titre' => 'Ecrã de ligação',
	'ecran_securite' => ' + ecrã de segurança @version@',
	'email' => 'email',
	'email_2' => 'email :',
	'en_savoir_plus' => 'Para saber mais',
	'entree_adresse_annuaire' => 'Endereço do directório',
	'entree_adresse_email' => 'O seu endereço email',
	'entree_adresse_email_2' => 'Endereço electrónico',
	'entree_base_donnee_1' => 'Endereço da base de dados',
	'entree_base_donnee_2' => '(Muitas vezes, este endereço corresponde ao do seu sítio, outras vezes, corresponde à menção «localhost», às vezes, fica totalmente vazio.)',
	'entree_biographie' => 'Curta biografia',
	'entree_chemin_acces' => '<b>Introduzir</b> o caminho de acesso :',
	'entree_cle_pgp' => 'A sua chave PGP',
	'entree_cle_pgp_2' => 'Chave PGP',
	'entree_contenu_rubrique' => '(Conteúdo da rubrica em poucas palavras.)',
	'entree_identifiants_connexion' => 'Os seus identificadores de ligação',
	'entree_identifiants_connexion_2' => 'Identifcadores de conexão',
	'entree_informations_connexion_ldap' => 'Por favor preencha este formulário com as informações de ligação ao seu anuário LDAP.
Essas informações devem poder ser fornecidas pelo administrador do sistema ou da rede',
	'entree_infos_perso' => 'Quem é você?',
	'entree_infos_perso_2' => 'Quem é o autor?',
	'entree_interieur_rubrique' => 'Dentro da rubrica :',
	'entree_liens_sites' => '<b>Ligação hipertexto</b> (referência, sítio a visitar...)',
	'entree_login' => 'O seu login',
	'entree_login_connexion_1' => 'O login de ligação',
	'entree_login_connexion_2' => '(Corresponde às vezes ao seu login de acesso ao FTP; outras vezes deixado vazio.)',
	'entree_mot_passe' => 'A sua palavra-passe',
	'entree_mot_passe_1' => 'A palavra-passe de ligação',
	'entree_mot_passe_2' => '(Corresponde, às vezes, à sua palavra-passe para o FTP; outras vezes fica vazio)',
	'entree_nom_fichier' => 'Por favor introduza o nome do ficheiro @texte_compresse@:',
	'entree_nom_pseudo' => 'O seu nome ou o seu pseudónimo',
	'entree_nom_pseudo_1' => '(O seu nome ou o seu pseudónimo)',
	'entree_nom_pseudo_2' => 'Nome ou pseudónimo',
	'entree_nom_site' => 'O nome do seu sítio',
	'entree_nom_site_2' => 'Nome do sítio do autor',
	'entree_nouveau_passe' => 'Nova palavra-passe',
	'entree_passe_ldap' => 'Palavra-passe',
	'entree_port_annuaire' => 'O número de porta do anuário',
	'entree_signature' => 'Assinatura',
	'entree_titre_obligatoire' => '<b>Título</b> [Obrigatório]<br />',
	'entree_url' => 'O endereço (URL) do seu sítio',
	'entree_url_2' => 'Endereço (URL) do sítio',
	'erreur_connect_deja_existant' => 'Já existe um servidor com esse nome',
	'erreur_contenu_suspect' => 'Texto de caracteres de escape',
	'erreur_email_deja_existant' => 'Este endereço de correio electrónico já está registado.',
	'erreur_nom_connect_incorrect' => 'O nome de servidor não é autorizado',
	'erreur_plugin_attribut_balise_manquant' => 'Atributo @attribut@ em falta no marcador @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'A desinstalação do plugin falhou. No entanto, pode desactivá-lo.',
	'erreur_plugin_fichier_absent' => 'Ficheiro inexistente',
	'erreur_plugin_fichier_def_absent' => 'Ficheiro de definição inexistente',
	'erreur_plugin_nom_fonction_interdit' => 'Nome de função interdito',
	'erreur_plugin_nom_manquant' => 'Nome de plugin inexistente',
	'erreur_plugin_prefix_manquant' => 'Espaço de criação de nome não definido para este plugin ',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; inexistente no ficheiro de definição',
	'erreur_plugin_version_manquant' => 'Versão de plugin inexistente',
	'erreur_type_fichier' => 'Tipo de ficheiro incorrecto',

	// H
	'htaccess_a_simuler' => 'Atenção: a configuração do servidor HTTP ignora @htaccess@. Para garantir uma boa segurança, deve alterar esta configuração. Alternativamente, deve assegurar que as constantes @constantes@ (definíveis no ficheiro mes_options.php) têm como valores diretórios fora de @document_root@.',
	'htaccess_inoperant' => 'htaccess inoperacional',

	// I
	'ical_info1' => 'Esta página apresenta muitos modos de permanecer em contacto com as actividades deste sítio.',
	'ical_info2' => 'Para mais informações sobre estas técnicas, consultar  <a href="@spipnet@">a documentação de SPIP</a>.',
	'ical_info_calendrier' => 'Estão disponíveis dois calendários. O primeiro é uma planta do sítio anunciando todos os artigos publicados. O segundo é pessoal e contém os anúncios editoriais assim como as últimas mensagens privadas : está reservado para si graças a uma chave pessoal, que pode modificar a qualquer momento com a renovação da sua palavra-passe.',
	'ical_methode_http' => 'Download',
	'ical_methode_webcal' => 'Sincronização (webcal://)',
	'ical_texte_js' => 'Uma linha de javascript permite-lhe facilmente exibir, em qualquer sítio que lhe pertença, os artigos recentes publicados neste sítio.',
	'ical_texte_prive' => 'Este calendário, de uso estritamente pessoal, informa sobre a actividade editorial privada deste sítio (tarefas e encontros pessoais, artigos e notícias propostos...).',
	'ical_texte_public' => 'Este calendário permite acompanhar a actividade pública deste sítio (artigos e notícias publicados).',
	'ical_texte_rss' => 'Pode vincular as novidades deste sítio em qualquer leitor de ficheiros de formato XML/RSS (Rich Site Summary). É também o formato que permite a SPIP ler as novidades publicadas em outros sítios que utilizam um formato de troca compatível.',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Ficheiros « backend »',
	'icone_accueil' => 'Início',
	'icone_activer_cookie' => 'Activar o cookie de correspondência',
	'icone_activite' => 'Actividade',
	'icone_admin_plugin' => 'Gerir plugins',
	'icone_administration' => 'Manutenção',
	'icone_afficher_auteurs' => 'Exibir os autores',
	'icone_afficher_visiteurs' => 'Exibir os visitantes',
	'icone_arret_discussion' => 'Não voltar a participar nesta discussão',
	'icone_calendrier' => 'Calendário',
	'icone_configuration' => 'Configuração',
	'icone_creer_auteur' => 'Criar um novo autor e associá-lo a este artigo',
	'icone_creer_mot_cle' => 'Criar uma nova palavra-chave e vinculá-la a este artigo',
	'icone_creer_rubrique_2' => 'Criar uma nova rubrica',
	'icone_developpement' => 'Desenvolvimento',
	'icone_edition' => 'Editar',
	'icone_ma_langue' => 'Idioma',
	'icone_mes_infos' => 'Minhas informações',
	'icone_mes_preferences' => 'Preferências',
	'icone_modifier_article' => 'Modificar este artigo',
	'icone_modifier_rubrique' => 'Modificar esta rubrica',
	'icone_publication' => 'Publicação',
	'icone_relancer_signataire' => 'Contactar o signatário novamente',
	'icone_retour' => 'Voltar',
	'icone_retour_article' => 'Voltar ao artigo',
	'icone_squelette' => 'Modelos',
	'icone_suivi_publication' => 'Monitorização da publicação',
	'icone_supprimer_cookie' => 'Suprimir o cookie de correspondência',
	'icone_supprimer_rubrique' => 'Suprimir esta rubrica',
	'icone_supprimer_signature' => 'Suprimir esta assinatura',
	'icone_valider_signature' => 'Validar esta assinatura',
	'image_administrer_rubrique' => 'Pode administrar esta rubrica',
	'impossible_modifier_login_auteur' => 'Impossível alterar o login.',
	'impossible_modifier_pass_auteur' => 'Impossível alterar a palavra-passe.',
	'info_1_article' => '1 artigo',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 mensagem',
	'info_1_mot_cle' => '1 palavra-chave',
	'info_1_rubrique' => '1 rubrica',
	'info_1_visiteur' => '1 visitante',
	'info_activer_cookie' => 'Pode activar um <b>cookie de correspondência</b>, o que lhe
 permitirá passar facilmente do sítio público ao sítio privado ',
	'info_activer_menu_developpement' => 'Mostrar o menu Desenvolvimento',
	'info_admin_etre_webmestre' => 'Conceder-me os direitos de webmaster',
	'info_admin_je_suis_webmestre' => 'Eu sou <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Conceder ao administrador os direitos de webmaster',
	'info_admin_webmestre' => 'Este administrador é <b>webmaster</b>',
	'info_administrateur' => 'Administrador',
	'info_administrateur_1' => 'Administrador',
	'info_administrateur_2' => 'do sítio (<i>utilize com precaução</i>)',
	'info_administrateur_site_01' => 'Se for o administrador do sítio, por favor',
	'info_administrateur_site_02' => 'clicar sobre esta ligação',
	'info_administrateurs' => 'Administradores',
	'info_administrer_rubrique' => 'Pode administrar esta rubrica',
	'info_adresse' => 'ao endereço :',
	'info_adresse_desinscription' => 'Endereço de cancelamento da subscrição: ',
	'info_adresse_url' => 'Endereço (URL) do sítio público',
	'info_afficher_par_nb' => 'Exibir',
	'info_aide_en_ligne' => 'Ajuda online SPIP',
	'info_ajout_image' => 'Quando acrescentar imagens como documentos ligados a um artigo,
 SPIP pode criar para si, automaticamente, vinhetas (miniaturas) das
 imagens inseridas. Isso permite por exemplo criar
 automaticamente uma galeria ou um portfolio.',
	'info_ajouter_rubrique' => 'Acrescentar uma rubrica a administrar :',
	'info_annonce_nouveautes' => 'Anúncio das novidades',
	'info_article' => 'artigo',
	'info_article_2' => 'artigos',
	'info_article_a_paraitre' => 'Os artigos pós-datados a publicar',
	'info_articles_02' => 'artigos',
	'info_articles_2' => 'Artigos',
	'info_articles_auteur' => 'Os artigos deste autor',
	'info_articles_miens' => 'Os meus artigos',
	'info_articles_tous' => 'Todos os artigos',
	'info_articles_trouves' => 'Artigos encontrados',
	'info_attente_validation' => 'Os seus artigos à espera de validação',
	'info_aucun_article' => 'Nenhum artigo',
	'info_aucun_auteur' => 'Nenhum autor',
	'info_aucun_message' => 'Sem mensagens',
	'info_aucun_rubrique' => 'Sem rubricas',
	'info_aujourdhui' => 'hoje :',
	'info_auteur_gere_rubriques' => 'Este autor gere as seguintes secções:',
	'info_auteur_gere_toutes_rubriques' => 'Este autor gere <b>todas as secções</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Eu administro <b>todas as rubricas</b>',
	'info_auteurs' => 'Os autores',
	'info_auteurs_par_tri' => 'Autores@partri@',
	'info_auteurs_trouves' => 'Autores encontrados',
	'info_authentification_externe' => 'Autenticação externa',
	'info_avertissement' => 'Aviso',
	'info_barre_outils' => 'com a sua barra de ferramentas?',
	'info_base_installee' => 'A estrutura da sua base de dados está instalada.',
	'info_bio' => 'Biografia',
	'info_cache_desactive' => 'A cache encontra-se temporariamente desactivada.',
	'info_chapeau' => 'Cabeçalho',
	'info_chapeau_2' => 'Cabeçalho :',
	'info_chemin_acces_1' => 'Opções : <b>Caminho de acesso no diretório</b>',
	'info_chemin_acces_2' => 'Doravante, deve configurar o caminho de acesso às informações no anuário. Esta informação é indispensável para ler os perfis de utilizador armazenados no anuário.',
	'info_chemin_acces_annuaire' => 'Opções : <b>Caminho de acesso no diretório',
	'info_choix_base' => 'Terceira etapa :',
	'info_classement_1' => '<sup>er</sup> no @liste@',
	'info_classement_2' => '<sup>e</sup> no @liste@',
	'info_code_acces' => 'Não se esqueça dos seus próprios códigos de acesso !',
	'info_config_suivi' => 'Se este endereço corresponder a uma mailing-list, pode indicar, a seguir, o endereço no qual os participantes no sítio podem inscrever-se. Este endereço pode ser uma URL (por exemplo a página de inscrição na lista pela Web), ou um endereço email com um assunto específico (por exemplo: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => ' Pode assinar a  mailing-list deste sítio. Receberá então, por correio electrónico, os anúncios de artigos e de notícias propostos para publicação.',
	'info_confirmer_passe' => 'Confirmar esta nova palavra-passe',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atenção: os campos seguintes foram modificados anteriormente. As suas alterações a estes campos não foram portanto guardadas. ',
	'info_conflit_edition_differences' => 'Diferenças:',
	'info_conflit_edition_version_enregistree' => 'Versão guardada :',
	'info_conflit_edition_votre_version' => 'A sua versão:',
	'info_connexion_base' => 'Segunda etapa: <b>Teste de ligação à base de dados</b>',
	'info_connexion_base_donnee' => 'Ligação à sua base de dados',
	'info_connexion_ldap_ok' => 'A ligação LDAP foi bem sucedida.</b><p> Pode passar para a etapa seguinte.</p>',
	'info_connexion_mysql' => 'Primeira etapa : <b>A sua ligação SQL<b>',
	'info_connexion_ok' => 'A ligação foi bem sucedida.',
	'info_contact' => 'Contacto',
	'info_contenu_articles' => 'Conteúdo dos artigos',
	'info_contributions' => 'Contributos',
	'info_creation_paragraphe' => 'Para criar parágrafos, deixe simplesmente linhas vazias.',
	'info_creation_rubrique' => 'Antes de poder escrever artigos, <br />deve criar pelo menos uma rubrica.<br />',
	'info_creation_tables' => 'Quarta etapa : <b>Criação das tabelas da base de dados<b>',
	'info_creer_base' => '<b>Criar</b> uma nova base de dados',
	'info_dans_rubrique' => 'Na rubrica :',
	'info_date_publication_anterieure' => 'Data de publicação anterior:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENTO DESTE SÍTIO :',
	'info_derniere_etape' => 'Última etapa : <b>Terminou !',
	'info_descriptif' => 'Descrição:',
	'info_desinstaller_plugin' => 'elimina os dados e desactiva o plugin',
	'info_discussion_cours' => 'Discussões em curso',
	'info_ecrire_article' => 'Antes de poder escrever artigos, deve criar pelo menos uma rubrica.',
	'info_email_envoi' => 'Endereço de email de envio (opcional)',
	'info_email_envoi_txt' => 'Indique aqui o endereço a utilizar para enviar os emails (se não for o caso, o endereço do destinatário será utilizado como endereço de envio) :',
	'info_email_webmestre' => 'Endereço e-mail do webmaster ',
	'info_envoi_email_automatique' => 'Envio automático de mails',
	'info_envoyer_maintenant' => 'Enviar agora',
	'info_etape_suivante' => 'Passar para a seguinte etapa',
	'info_etape_suivante_1' => 'Pode passar para a etapa seguinte',
	'info_etape_suivante_2' => 'Pode passar para a etapa seguinte',
	'info_exceptions_proxy' => 'Excepções para o proxy',
	'info_exportation_base' => 'exportação da base para @archive@',
	'info_facilite_suivi_activite' => 'A fim de facilitar o acompanhamento da actividade
 editorial do sítio, SPIP pode fazer chegar por email, por exemplo
 a uma <i>mailing-list</i> dos redactores, o anúncio dos pedidos de
 publicação e das validações de artigos.', # MODIF
	'info_fichiers_authent' => 'Ficheiros de autenticação « .htpasswd »',
	'info_forums_abo_invites' => 'O seu sítio contém fóruns por assinatura; os visitantes são convidados a registar-se no sítio público.',
	'info_gauche_admin_tech' => '<b>Esta página está acessível apenas aos responsáveis pelo site.</b><p> Ela dá acesso às diferentes funções de manutenção técnica. Algumas dessas funções possuem um processo específico de autenticação que exige acesso FTP ao sítio.</p>',
	'info_gauche_admin_vider' => '<b>Esta página é acessível apenas aos responsáveis pelo sítio.</b><p> Ela dá acesso às diferentes funções de manutenção técnica. Algumas dessas funções possuem um processo específico de autenticação que exige acesso FTP ao sítio web</p>',
	'info_gauche_auteurs' => 'Encontrará aqui todos os autores do sítio.
Os estatuto dos autores é indicado pela cor dos ícones (administrador = verde; redactor = amarelo).',
	'info_gauche_auteurs_exterieurs' => 'Os autores externos, sem acesso ao sítio, são indicados por um ícone azul;
os autores apagados, por um ícone cinzento.',
	'info_gauche_messagerie' => 'A caixa de correio permite-lhe trocar mensagens entre redactores, conservar memorandos (para o seu uso pessoal) ou exibir anúncios na página de abertura do espaço privado (se for administrador).',
	'info_gauche_statistiques_referers' => 'Esta página apresenta a lista dos  <i>referers</i>, ou seja, dos sítios que contêm links para o seu sítio, unicamente para ontem e hoje; esta lista é actualizada a cada 24 horas.',
	'info_gauche_visiteurs_enregistres' => 'Encontrará aqui os visitantes registados
 no espaço público do sítio (fóruns por assinatura).',
	'info_generation_miniatures_images' => 'Geração de miniaturas das imagens',
	'info_gerer_trad_objets' => '@objets@ : gerir as ligações de tradução',
	'info_hebergeur_desactiver_envoi_email' => 'Alguns serviços de hospedagem desactivam o envio automático de
 e-mails a partir dos seus  servidores. Nesse caso, as seguintes
 funcionalidades de SPIP não funcionarão.',
	'info_hier' => 'ontem :',
	'info_identification_publique' => 'A sua identidade pública...',
	'info_image_process' => 'Seleccione o melhor método para criar as vinhetas clicando sobre a imagem correspondente.',
	'info_image_process2' => '<b>N.B.</b> <i> Se nenhuma imagem aparece, então o servidor que alberga o seu sítio não foi configurado para utilizar tais ferramentas. Se deseja utilizar essas funções, contacte o responsavel técnico e peça as extensões  «GD» ou «Imagick».</i>',
	'info_images_auto' => 'Imagens calculadas automaticamente',
	'info_informations_personnelles' => 'Quinta etapa : <b>Informações pessoais<b>',
	'info_inscription' => 'Inscrição em ',
	'info_inscription_automatique' => 'Inscrição automática de novos redactores',
	'info_jeu_caractere' => 'Conjunto de caracteres do sítio',
	'info_jours' => 'dias',
	'info_laisser_champs_vides' => 'deixar estes campos vazios)',
	'info_langues' => 'Idiomas do sítio',
	'info_ldap_ok' => 'A autenticação LDAP está instalada.',
	'info_lien_hypertexte' => 'Hiperligação :',
	'info_liste_nouveautes_envoyee' => 'A lista de novidades foi enviada.',
	'info_liste_redacteurs_connectes' => 'Lista dos redactores ligados',
	'info_login_existant' => 'Este login já existe.',
	'info_login_trop_court' => 'Login demasiado curto.',
	'info_login_trop_court_car_pluriel' => 'O login deve conter pelo menos @nb@ caracteres.',
	'info_logos' => 'Os logos',
	'info_maximum' => 'máximo :',
	'info_meme_rubrique' => 'Na mesma rubrica',
	'info_message_en_redaction' => 'As suas mensagens em rascunho',
	'info_message_technique' => 'Mensagem técnica:',
	'info_messagerie_interne' => 'Correio interno',
	'info_mise_a_niveau_base' => 'melhoramento da sua base de dados SQL',
	'info_mise_a_niveau_base_2' => '{{Atenção!}} Instalou uma versão
 dos ficheiros SPIP {anterior} à que se encontrava
 antes neste sítio: a sua base de dados corre o risco de se perder
 e o seu sítio já não funcionará .<br />{{Re-instalar os
 ficheiros de SPIP.}}',
	'info_modification_enregistree' => 'As suas modificações foram guardadas',
	'info_modifier_auteur' => 'Modifcar o autor :',
	'info_modifier_rubrique' => 'Modificar a rubrica :',
	'info_modifier_titre' => 'Modificar : @titre@',
	'info_mon_site_spip' => 'O meu sítio SPIP',
	'info_moyenne' => 'média :',
	'info_multi_cet_article' => 'Idioma deste artigo :',
	'info_multi_langues_choisies' => 'Por favor seleccione a seguir os idiomas à disposição dos redactores do seu sítio.
 Os idiomas já utilizados no seu sítio (exibidos em primeiro lugar) não podem ser desactivados.',
	'info_multi_objets' => '@objets@ : activar o menu de idioma',
	'info_multi_secteurs' => '... só para as rubricas situadas na raíz ?',
	'info_nb_articles' => '@nb@ artigos',
	'info_nb_auteurs' => '@nb@ autores',
	'info_nb_messages' => '@nb@ mensagens',
	'info_nb_mots_cles' => '@nb@ palavras-chave',
	'info_nb_rubriques' => '@nb@ rubricas',
	'info_nb_visiteurs' => '@nb@ visitantes',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome do destinatário',
	'info_nom_pas_conforme' => 'as tags html não são autorizadas',
	'info_nom_site' => 'Nome do seu sítio',
	'info_nombre_articles' => '@nb_articles@ artigos,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sítios,',
	'info_non_deplacer' => 'Não deslocar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pode enviar regularmente o anúncio das últimas novidades do sítio
 (artigos e notícias recentemente publicados).',
	'info_non_envoi_liste_nouveautes' => 'Não enviar a lista das novidades',
	'info_non_modifiable' => 'não pode ser modificado',
	'info_non_suppression_mot_cle' => 'Não quero suprimir esta palavra-chave.',
	'info_notes' => 'Notas',
	'info_nouvel_article' => 'Novo artigo',
	'info_nouvelle_traduction' => 'Nova tradução :',
	'info_numero_article' => 'ARTIGO NÚMERO :',
	'info_obligatoire_02' => '(obrigatório)',
	'info_option_accepter_visiteurs' => 'Aceitar a inscrição de visitantes do sítio público',
	'info_option_ne_pas_accepter_visiteurs' => 'Recusar a inscrição de visitantes',
	'info_options_avancees' => 'OPÇÕES AVANÇADAS',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Página proibida',
	'info_par_nom' => 'por nome',
	'info_par_nombre_article' => 'por número de artigos',
	'info_par_statut' => 'por estado',
	'info_par_tri' => '’(por @tri@)’',
	'info_passe_trop_court' => 'Palavra-passe demasiado curta.',
	'info_passe_trop_court_car_pluriel' => 'A palavra-passe deve conter pelo menos @nb@ caracteres.',
	'info_passes_identiques' => 'As duas palavras-passe não são idênticas.',
	'info_plus_cinq_car' => 'mais de 5 caracteres',
	'info_plus_cinq_car_2' => '(Mais de 5 caracteres)',
	'info_plus_trois_car' => '(Mais de 3 caracteres)',
	'info_popularite' => 'popularidade : @popularite@ ; visitas : @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum :',
	'info_pour' => 'para',
	'info_preview_texte' => 'É possível visualizar os vários elementos editoriais do site que têm pelo menos o estatuto "proposto", bem como os artigos em processo de escrita dos quais se é o autor. Esta funcionalidade deve estar disponível para administradores, editores ou para ninguém?',
	'info_procedez_par_etape' => 'proceder etapa por etapa',
	'info_procedure_maj_version' => 'o procedimento de actualização deve ser lançado para adaptar
a base de dados à nova versão de SPIP.',
	'info_proxy_ok' => 'Proxy testado com sucesso.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Os seus artigos publicados online',
	'info_question_accepter_visiteurs' => 'Se os parâmetros do seu site prevêem o registo de visitantes sem acesso ao espaço privado, por favor, active a opção abaixo:',
	'info_question_inscription_nouveaux_redacteurs' => 'Aceita as inscrições de novos redactores a
 partir do sítio público? Se aceitar, os visitantes poderão inscrever-se
 a partir de um formulário automatizado e acederão então ao espaço privado para
propor os seus próprios artigos. <blockquote><i>Durante a fase de inscrição, os utilizadores recebem um e-mail automático
fornecendo-lhes os seus códigos de acesso ao sítio privado. Alguns
serviços de hospedagem desactivam o envio de e-mails a partir dos seus
 servidores: nesse caso, a inscrição automática é impossível.',
	'info_qui_edite' => '@nom_auteur_modif@ modificou o conteúdo há @date_diff@ minutos',
	'info_racine_site' => 'Raiz do sítio',
	'info_recharger_page' => 'Por favor volte a carregar esta página daqui a pouco.',
	'info_recherche_auteur_zero' => 'Nenhum resultado para "@cherche_auteur@".',
	'info_recommencer' => 'Por favor tente de novo.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'tendo acesso ao espaço privado(<i>recomendado</i>)',
	'info_redacteurs' => 'Redactores',
	'info_redaction_en_cours' => 'EM CURSO DE REDACÇÃO',
	'info_redirection' => 'Redirigir',
	'info_redirection_activee' => 'O redireccionamento está activado.',
	'info_redirection_boucle' => 'Está a tentar redireccionar o artigo para este mesmo artigo.',
	'info_redirection_desactivee' => 'O redireccionamento foi eliminado.',
	'info_refuses' => 'Os seus artigos recusados',
	'info_reglage_ldap' => 'Opções : <b>Acerto da importação LDAP</b>',
	'info_renvoi_article' => '<b>Redireccionar.</b> Este artigo remete para a página:',
	'info_reserve_admin' => 'Só os administradores podem modificar este endereço.',
	'info_restreindre_rubrique' => 'Limitar a gestão à rubrica : ',
	'info_resultat_recherche' => 'Resultados da pesquisa ;',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas encontradas',
	'info_sans_titre' => 'Sem título',
	'info_selection_chemin_acces' => '<b>Seleccione</b> a seguir o caminho de acesso no anuário :',
	'info_signatures' => 'assinaturas',
	'info_site' => 'Sítio',
	'info_site_2' => 'sítio :',
	'info_site_min' => 'sítio',
	'info_site_reference_2' => 'Sítio referenciado',
	'info_site_web' => 'Sítio web :',
	'info_sites' => 'sítios',
	'info_sites_lies_mot' => 'Os sítios referenciados ligados a esta palavra-chave',
	'info_sites_proxy' => 'Utilizar um proxy',
	'info_sites_trouves' => 'Sítios encontrados',
	'info_sous_titre' => 'Sub-título :',
	'info_statut_administrateur' => 'Administrador',
	'info_statut_auteur' => 'Estatuto deste autor :',
	'info_statut_auteur_2' => 'Eu sou',
	'info_statut_auteur_a_confirmer' => 'Registo a confirmar',
	'info_statut_auteur_autre' => 'Outro estado:',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatuto por defeito dos utilizadores importados',
	'info_statut_utilisateurs_2' => 'Escolha o estatuto atribuído às pessoas presentes no anuário LDAP quando elas se ligam pela primeira vez. Poderá depois modificar este valor para cada autor, caso a caso.',
	'info_suivi_activite' => 'Acompanhamento da actividade editorial',
	'info_surtitre' => 'Antetítulo',
	'info_syndication_integrale_1' => 'O seu sítio propõe os ficheiros redifundidos (ver « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Deseja enviar os artigos completos ou apenas um resumo de algumas centenas de caracteres?',
	'info_table_prefix' => 'Pode modificar o prefixo do nome das tabelas das bases de dados. (Precisa de o fazer se estiver a instalar vários sítios na mesma base de dados.) O prefixo tem de ser escrito sem acentos, em minúsculas e sem espaços.',
	'info_taille_maximale_images' => 'SPIP testará o tamanho máximo de imagem que pode processar (em milhões de pixels).<br /> As imagens maiores não serão reduzidas.',
	'info_taille_maximale_vignette' => 'Tamanho máximo das vinhetas geradas pelo sistema :',
	'info_terminer_installation' => 'Pode agora acabar o procedimento de instalação tipo.',
	'info_texte' => 'Texto',
	'info_texte_explicatif' => 'Texto explicativo',
	'info_texte_long' => '(o texto é comprido : aparece, por isso, em muitas partes que serão coladas depois da validação.)',
	'info_texte_message' => 'Texto da sua mensagem :',
	'info_texte_message_02' => 'Texto da mensagem',
	'info_titre' => 'Título :',
	'info_total' => 'total :',
	'info_tous_articles_en_redaction' => 'Todos os artigos em curso de redacção',
	'info_tous_articles_presents' => 'Todos os artigos publicados nesta rubrica',
	'info_tous_articles_refuses' => 'Todos os artigos rejeitados',
	'info_tous_les' => 'todos os',
	'info_tout_site' => 'Todo o sítio',
	'info_tout_site2' => 'O artigo não está traduzido neste idioma.',
	'info_tout_site3' => 'O artigo foi traduzido neste idioma, mas foram feitas modificações ao artigo original. A tradução necessita ser actualizada.',
	'info_tout_site4' => 'O artigo foi traduzido neste idioma e a tradução está actual.',
	'info_tout_site5' => 'Artigo original.',
	'info_tout_site6' => '<b>Atenção:</b> só os artigos originais são mostrados.
As traduções estão associadas ao original,
numa cor que indica o seu estado:',
	'info_traductions' => 'Traduções',
	'info_travail_colaboratif' => 'Trabalho colaborativo sobre os artigos',
	'info_un_article' => 'um artigo',
	'info_un_site' => 'um sítio',
	'info_une_rubrique' => 'uma rubrica,',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL do proxy',
	'info_url_proxy_pas_conforme' => 'o URL do proxy não é válido.',
	'info_url_site_pas_conforme' => 'O URL do sítio não é válido',
	'info_url_test_proxy' => 'URL de teste',
	'info_urlref' => 'Ligação hipertexto :',
	'info_utilisation_spip' => 'Pode começar agora a utilizar o sistema de publicação assistida...',
	'info_visites_par_mois' => 'Exibição por mês :',
	'info_visiteur_1' => 'Visitante',
	'info_visiteur_2' => 'do sítio público',
	'info_visiteurs' => 'Visitantes',
	'info_visiteurs_02' => 'Visitantes do sítio público',
	'info_webmestre_forces' => 'Os webmasters são actualmente definidos em <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Endereço da base de dados atribuído pelo serviço de hospedagem',
	'install_connect_ok' => 'A nova base de dados foi declarada usando o nome de servidor @connect@.',
	'install_echec_annonce' => 'A instalação vai provavelmente falhar,ou criar um sítio não funcional',
	'install_extension_mbstring' => 'O SPIP não funciona com :',
	'install_extension_php_obligatoire' => 'O SPIP exige a extensão php :',
	'install_login_base_hebergeur' => 'Login de ligação atribuído pelo serviço de hospedagem',
	'install_nom_base_hebergeur' => 'Nome da base de dados atribuído pelo serviço de hospedagem:',
	'install_pas_table' => 'A base de dados não tem tabelas',
	'install_pass_base_hebergeur' => 'Palavra-passe atribuída pelo serviço de hospedagem',
	'install_php_version' => 'Esta versão de PHP @version@ é demasiado curta (minimum = @minimum@)',
	'install_select_langue' => 'Seleccione um idioma e depois clique no botão " seguinte " para lançar o procedimento de instalação.',
	'install_select_type_db' => 'Indicar o tipo de base de dados :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidor da base de dados atribuído pelo serviço de hospedagem',
	'install_table_prefix_hebergeur' => 'Prefixo de tabela atribuído pelo serviço de hospedagem:',
	'install_tables_base' => 'Tabelas da base de dados',
	'install_types_db_connus' => 'SPIP pode usar <b>MySQL</b> (o mais comum), <b>PostgreSQL</b> e <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'O suporte de <b>PostgreSQL</b> está proposto a nível experimental',
	'instituer_erreur_statut_a_change' => 'O estado já tinha sido modificado',
	'instituer_erreur_statut_non_autorise' => 'Não pode seleccionar este estado',
	'intem_redacteur' => 'redactor',
	'intitule_licence' => 'Licença',
	'item_accepter_inscriptions' => 'Aceitar as inscrições',
	'item_activer_messages_avertissement' => 'Activar as mensagens de aviso',
	'item_administrateur_2' => 'administrador',
	'item_afficher_calendrier' => 'Exibir o calendário',
	'item_autoriser_syndication_integrale' => 'Incluir artigos completos nos ficheiros de redifusão',
	'item_choix_administrateurs' => 'os administradores',
	'item_choix_generation_miniature' => 'Gerar automaticamente as miniaturas das imagens.',
	'item_choix_non_generation_miniature' => 'Não gerar miniaturas das imagens.',
	'item_choix_redacteurs' => 'os redactores',
	'item_choix_visiteurs' => 'os visitadores do sítio público',
	'item_creer_fichiers_authent' => 'Criar os ficheiros .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activar as mensagens e a agenda',
	'item_mots_cles_association_articles' => 'aos artigos',
	'item_mots_cles_association_rubriques' => 'às rubricas',
	'item_mots_cles_association_sites' => 'aos sítios referenciados ou vinculados.',
	'item_non' => 'Não',
	'item_non_accepter_inscriptions' => 'Não aceitar as inscrições',
	'item_non_activer_messages_avertissement' => 'Não há mensagens de aviso',
	'item_non_afficher_calendrier' => 'Não exibir no calendário',
	'item_non_autoriser_syndication_integrale' => 'Enviar apenas um resumo',
	'item_non_creer_fichiers_authent' => 'Não criar estes ficheiros',
	'item_non_messagerie_agenda' => 'Desactivar as mensagens e a agenda',
	'item_non_publier_articles' => 'Não publicar os artigos antes da data de publicação fixada.',
	'item_nouvel_auteur' => 'Novo autor',
	'item_nouvelle_rubrique' => 'Nova rubrica',
	'item_oui' => 'Sim',
	'item_publier_articles' => 'Publicar os artigos, seja qual for a sua data de publicação.',
	'item_reponse_article' => 'Resposta ao artigo',
	'item_visiteur' => 'visitante',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra de ferramentas',
	'label_bando_outils_afficher' => 'Exibir as ferramentas',
	'label_bando_outils_masquer' => 'Ocultar as ferramentas',
	'label_choix_langue' => 'Seleccione o seu idioma',
	'label_nom_fichier_connect' => 'Indique o nome para este servidor',
	'label_slogan_site' => 'Slogan do sítio',
	'label_taille_ecran' => 'Largura do ecrã',
	'label_texte_et_icones_navigation' => 'Menu de navegação',
	'label_texte_et_icones_page' => 'Exibição da página',
	'ldap_correspondance' => 'sucessão do campo @champ@',
	'ldap_correspondance_1' => 'Sucessão dos campos LDAP',
	'ldap_correspondance_2' => 'Para cada um destes campos SPIP, indique o nome do campo LDAP correspondente. Deixe em branco se não o deseja preenchido. Separe com espaços ou vírgulas, para tentar vários campos LDAP.',
	'lien_ajouter_auteur' => 'Acrescentar este autor',
	'lien_ajouter_une_rubrique' => 'Adicionar esta rubrica',
	'lien_email' => 'email',
	'lien_nom_site' => 'NOME DO SÍTIO',
	'lien_rapide_contenu' => 'Ir para o conteúdo',
	'lien_rapide_navigation' => 'Ir para a navegação',
	'lien_rapide_recherche' => 'Ir para a pesquisa',
	'lien_retirer_auteur' => 'Remover o autor',
	'lien_retirer_rubrique' => 'Eliminar a rubrica',
	'lien_retirer_tous_auteurs' => 'Eliminar todos os autores',
	'lien_retirer_toutes_rubriques' => 'Remover todas as rubricas',
	'lien_site' => 'sítio',
	'lien_tout_decocher' => 'Desmarcar tudo',
	'lien_tout_deplier' => 'Expandir tudo',
	'lien_tout_replier' => 'Recolher tudo',
	'lien_tout_supprimer' => 'Eliminar tudo',
	'lien_trier_nom' => 'Seleccionar por nome',
	'lien_trier_nombre_articles' => 'seleccionar por número de artigos',
	'lien_trier_statut' => 'Seleccionar por estatuto',
	'lien_voir_en_ligne' => 'VER EM LINHA',
	'logo_article' => 'Logotipo do artigo',
	'logo_auteur' => 'Logotipo do autor ',
	'logo_rubrique' => 'Logotipo da rubrica',
	'logo_site' => 'Logotipo deste sítio',
	'logo_standard_rubrique' => 'Logotipo modelo das rubricas',
	'logo_survol' => 'Logotipo "mouseover"',

	// M
	'menu_aide_installation_choix_base' => 'Escolha da sua base',
	'module_fichier_langue' => 'Ficheiro de idioma',
	'module_raccourci' => 'Atalhos',
	'module_texte_affiche' => 'Texto exibido',
	'module_texte_explicatif' => 'Pode inserir os seguintes atalhos nos esqueletos do seu sítio público. Serão automaticamente traduzidos para os vários idiomas nos quais há um ficheiro de idioma.',
	'module_texte_traduction' => 'O ficheiro de idioma « @module@ » está disponível em :',
	'mois_non_connu' => 'não conhecido',

	// N
	'nouvelle_version_spip' => 'A versão @version@ de SPIP está disponível',
	'nouvelle_version_spip_majeure' => 'Um novo SPIP @version@ está disponível',

	// O
	'onglet_contenu' => 'Conteúdo',
	'onglet_declarer_une_autre_base' => 'Declarar outra base de dados',
	'onglet_discuter' => 'Discussão',
	'onglet_interactivite' => 'Interactividade',
	'onglet_proprietes' => 'Propriedades',
	'onglet_repartition_actuelle' => 'actualmente',
	'onglet_sous_rubriques' => 'Sub-rubricas',

	// P
	'page_pas_proxy' => 'Esta página não deve passar através do proxy',
	'pas_de_proxy_pour' => 'Se necessário, indique a que máquinas ou domínios este proxy não se deve aplicar (por exemplo : @exemple@)',
	'phpinfo' => 'Configuração PHP',
	'plugin_charge_paquet' => 'Carregamento do ficheiro @name@',
	'plugin_charger' => 'Download',
	'plugin_erreur_charger' => 'erro : impossível carregar @zip@',
	'plugin_erreur_droit1' => 'Não pode escrever no directório <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Por favor verifique as autorizações para este directório (e crie o directório se necessário). Alternativamente, instale os ficheiros por FTP.',
	'plugin_erreur_zip' => 'falha pclzip : erro @status@',
	'plugin_etat_developpement' => 'em desenvolvimento',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estável',
	'plugin_etat_test' => 'em teste',
	'plugin_impossible_activer' => 'Impossível activar o plugin @plugin@',
	'plugin_info_automatique1' => 'Se deseja autorizar a instalação automática de plugins, por favor:',
	'plugin_info_automatique1_lib' => 'Se deseja que a biblioteca seja instalada automaticamente, por favor:',
	'plugin_info_automatique2' => 'criar um directório <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Verifique se o servidor está autorizado a escrever neste directório.',
	'plugin_info_automatique_creer' => 'a criar na raiz do sítio.',
	'plugin_info_automatique_exemples' => 'exemplos:',
	'plugin_info_automatique_ftp' => 'Pode instalar os plugins, por FTP, no directório <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Alguns plugins precisam de estar aptos a carregar ficheiros no directório <code>lib/</code>. Este directório deve ser criado na raiz do sítio.',
	'plugin_info_automatique_liste' => 'As suas listas de plugins :',
	'plugin_info_automatique_liste_officielle' => 'os plugins oficiais',
	'plugin_info_automatique_liste_update' => 'Actualizar as listas',
	'plugin_info_automatique_ou' => 'ou...',
	'plugin_info_automatique_select' => 'Seleccione um plugin abaixo: SPIP irá carregá-lo e instalá-lo no directório <code>@rep@</code>. Se o plugin já existir, será actualizado.',
	'plugin_info_credit' => 'Créditos',
	'plugin_info_erreur_xml' => 'A declaração do plugin está incorrecta',
	'plugin_info_install_ok' => 'Instalado com sucesso',
	'plugin_info_necessite' => 'Requer:',
	'plugin_info_non_compatible_spip' => 'O plugin é incompatível com esta versão de SPIP',
	'plugin_info_plugins_dist_1' => 'Os plugins seguintes estão carregados e activados no directório @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Não podem ser desactivados.',
	'plugin_info_telecharger' => 'carregar de @url@ e instalar em @rep@',
	'plugin_info_upgrade_ok' => 'Actualizado com sucesso',
	'plugin_librairies_installees' => 'Bibliotecas instaladas',
	'plugin_necessite_extension_php' => 'Requer a extensão PHP @plugin@ em @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Requer a extensão PHP @plugin@',
	'plugin_necessite_lib' => 'Este plugin requer a biblioteca @lib@',
	'plugin_necessite_php' => 'Requer @plugin@ em versão @version@.',
	'plugin_necessite_plugin' => 'Requer o plugin @plugin@ em versão @version@ ou mais recente.',
	'plugin_necessite_plugin_sans_version' => 'Requer o plugin @plugin@',
	'plugin_necessite_spip' => 'Requer SPIP em version @version@ ou mais recente.',
	'plugin_source' => 'fonte: ',
	'plugin_titre_automatique' => 'Instalação automática',
	'plugin_titre_automatique_ajouter' => 'Adicionar plugins',
	'plugin_titre_installation' => 'Instalação do plugin @plugin@',
	'plugin_titre_modifier' => 'Os meus plugins',
	'plugin_utilise_extension_php' => 'A extensão PHP @plugin@ deve estar na versão @version@.',
	'plugin_utilise_php' => '@plugin@ deve estar na versão @version@.',
	'plugin_utilise_plugin' => 'O plugin @plugin@ deve estar na versão @version@.',
	'plugin_zip_active' => 'Continue para activar',
	'plugin_zip_adresse' => 'Para carregar um ficheiro zip de plugin, ou uma lista de plugins, introduza o caminho abaixo.',
	'plugin_zip_adresse_champ' => 'Endereço do plugin ou da lista',
	'plugin_zip_content' => 'Contém os seguintes ficheiros  (@taille@),<br /> prontos a ser instalados no directório <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'O ficheiro @zip@ foi descomprimido e instalado.',
	'plugin_zip_installe_rep_finie' => 'O ficheiro @zip@ foi descompactado e instalado no directório @rep@',
	'plugin_zip_installer' => 'Agora pode instalar.',
	'plugin_zip_telecharge' => 'O ficheiro @zip@ foi carregado',
	'plugins_actif_aucun' => 'Sem plugins activados.',
	'plugins_actif_un' => 'Um plugin activado.',
	'plugins_actifs' => '@count@ plugins activados.',
	'plugins_actifs_liste' => 'Activados',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Um plugin disponível.',
	'plugins_disponibles' => '@count@ plugins disponíveis.',
	'plugins_erreur' => 'Erro nos plugins : @plugins@',
	'plugins_liste' => 'Lista de plugins',
	'plugins_liste_dist' => 'Plugins bloqueados',
	'plugins_recents' => 'Plugins recentes.',
	'plugins_tous_liste' => 'Todos',
	'plugins_vue_hierarchie' => 'Hierarquia',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Versão do protocolo:',

	// Q
	'queue_executer_maintenant' => 'Executar agora',
	'queue_info_purger' => 'Pode eliminar todas as tarefas em espera e pôr a zeros a lista de tarefas periódicas',
	'queue_nb_jobs_in_queue' => '@nb@ tarefas em espera',
	'queue_next_job_in_nb_sec' => 'Próxima tarefa em @nb@ s',
	'queue_no_job_in_queue' => 'Sem tarefas em espera',
	'queue_one_job_in_queue' => '1 tarefa em espera',
	'queue_priorite_tache' => 'prioridade',
	'queue_purger_queue' => 'Pôr a zeros a lista de tarefas',
	'queue_titre' => 'Lista de tarefas',

	// R
	'repertoire_plugins' => 'Directório :',
	'required' => '(obrigatório)',

	// S
	'sans_heure' => 'tempo não especificado',
	'statut_admin_restreint' => 'administrador restrito',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'Tarefas CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tarefa CRON @function@ (todas as @nb@ s)',
	'taille_cache_image' => 'As imagens calculadas automaticamente pelo SPIP (miniaturas dos documentos, títulos apresentados sob forma gráfica, funções matemáticas no formato TeX...) ocupam no directório @dir@ um total de @taille@.',
	'taille_cache_infinie' => 'Este sítio não prevê limitação de tamanho do directório de cache <code>CACHE/</code>.',
	'taille_cache_maxi' => 'SPIP tenta limitar o tamanho do diretório cache <code>CACHE/</code> deste sítio em cerca de <b>@octets@</b>.',
	'taille_cache_moins_de' => 'O tamanho da cache é menor do que @octets@.',
	'taille_cache_octets' => 'O tamanho da cache é actualmente cerca de  @octets@.',
	'taille_cache_vide' => 'A cache está vazia.',
	'taille_repertoire_cache' => 'Tamanho do directório cache',
	'text_article_propose_publication' => 'Artigo proposto para publicação. Não hesite em dar a sua opinião graças ao fórum ligado a este artigo (no fundo da página).',
	'texte_acces_ldap_anonyme_1' => 'Alguns servidores LDAP não aceitam nenhum acesso anónimo. Nesse caso, é preciso especificar um identificador de acesso inicial a fim de poder depois procurar informações no anuário. Na maior parte dos casos, porém, os seguintes campos poderão ser deixados vazios.',
	'texte_admin_effacer_01' => 'Este comando apaga <i>todo</i> o conteúdo da base de dados,
inclusive <i>todos</i> os acessos de redactores e administradores. Depois de o ter executado, deverá
reinstalar SPIP para recriar uma nova base assim como uma primeira conta de administrador.',
	'texte_adresse_annuaire_1' => '(Se o seu anuário está instalado na mesma máquina que este sítio Web, trata-se de «localhost».)',
	'texte_ajout_auteur' => 'O seguinte autor foi acrescentado ao artigo :',
	'texte_annuaire_ldap_1' => 'Se tiver acesso a um anuário (LDAP), pode utilizá-lo para importar automaticamente utilizadores sob SPIP.',
	'texte_article_statut' => 'Este artigo está:',
	'texte_article_virtuel' => 'Artigo virtual',
	'texte_article_virtuel_reference' => '<b>Artigo virtual :</b> artigo referenciado no seu sítio SPIP, mas redirigido para uma outra URL. Para suprimir a redirecção, apague a URL acima.',
	'texte_aucun_resultat_auteur' => 'Nenhum resultado para "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Este site pode indicar permanentemente a lista dos redactores ligados, o que lhe permite trocar mensagens  em directo ( quando o correio está desactivado mais acima, a lista dos redactores está desactivada). Pode decidir não aparecer nesta lista (estando « invisível » para os outros utilizadores).',
	'texte_auteurs' => 'OS AUTORES',
	'texte_choix_base_1' => 'Escolha a sua base de dados :',
	'texte_choix_base_2' => 'O servidor SQL contém várias bases de dados.',
	'texte_choix_base_3' => '<b>Seleccione</b> a seguir a que lhe foi atribuida pelo seu serviço de hospedagem.',
	'texte_choix_table_prefix' => 'Prefixo das tabelas:',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementos',
	'texte_conflit_edition_correction' => 'Por favor compare as diferenças entre as duas versões. Pode também copiar as suas alterações e recomeçar.',
	'texte_connexion_mysql' => 'Consulte as informações fornecidas pelo seu serviço de hospedagem: deve encontrar nelas, se o seu hospedeiro suporta SQL, os códigos de ligação ao servidor SQL.',
	'texte_contenu_article' => '(Conteúdo do artigo em poucas palavras.)',
	'texte_contenu_articles' => 'Segundo a maqueta adoptada para o seu sítio, pode decidir
que alguns elementos dos artigos não são utilizados.
   Utilize a lista a seguir para indicar quais são os elementos disponíveis.',
	'texte_crash_base' => 'Se a sua base de dados foi
 destruída, pode tentar uma reparação
 automática.',
	'texte_creer_rubrique' => 'Antes de poder escrever artigos, <br /> deve criar uma rubrica.',
	'texte_date_creation_article' => 'DATA DE CRIAÇÃO DO ARTIGO:',
	'texte_date_creation_objet' => 'Data de criação:', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Data de redacção anterior :',
	'texte_date_publication_anterieure_nonaffichee' => 'Não exibir a data de redacção anterior',
	'texte_date_publication_article' => 'DATA DE PUBLICAÇÃO ONLINE:',
	'texte_date_publication_objet' => 'Data de publicação online:',
	'texte_definir_comme_traduction_rubrique' => 'Esta secção é uma tradução da secção número: ',
	'texte_descriptif_rapide' => 'Descrição rápida',
	'texte_effacer_base' => 'Apagar a base de dados SPIP',
	'texte_effacer_statistiques' => 'Apagar as estatísticas',
	'texte_en_cours_validation' => 'Os artigos e notícias seguintes estão propostos para publicação. Não hesite em dar a sua opinião graças aos fóruns que lhes estão ligados.',
	'texte_enrichir_mise_a_jour' => 'Pode enriquecer a paginação do seu texto, utilizando « atalhos tipográficos ».',
	'texte_fichier_authent' => '<b>Deverá o SPIP criar os ficheiros especiais<tt>.htpasswd-admin</tt> no directório @dossier@?</b>
<p>Estes ficheiros podem servir-lhe para restringir o acesso aos autores
e administradores a outras partes do seu sítio (por exemplo, um programa externo de estatísticas).<p>
Se não utilizar os ficheiros especiais, pode deixar esta opção no seu valor por omissão (não há criação de ficheiros).',
	'texte_informations_personnelles_1' => 'O sistema vai agora criar-lhe um acesso personalizado ao sítio',
	'texte_informations_personnelles_2' => '(Nota : se se tratar de uma reinstalação e se o seu acesso continua funcional, pode',
	'texte_introductif_article' => '(Texto introdutório do artigo.)',
	'texte_jeu_caractere' => 'Esta opção é útil se o seu sítio precisa de exibir alfabetos diferentes do alfabeto romano (ou  «ocidental») e seus derivados. Nesse caso, pode ser preferível mudar a definição por defeito para utilizar um conjunto de carácteres adequado; aconselhamos, em todos os casos, a proceder a experiências a fim de encontrar uma solução satisfatória. Se modificar este parâmetro, não esqueça também de adaptar o sítio público (balisa<tt>#CHARSET</tt>).',
	'texte_jeu_caractere_3' => 'O seu sítio usa actualmente o conjunto de caracteres:',
	'texte_jeu_caractere_4' => 'Se não corresponde aos seus dados actuais (pode ocorrer após restaurar a base de dados a partir de uma cópia de segurança), ou se <em> estiver a configurar este sítio </em> e deseja usar um conjunto diferente de caracteres, por favor indique-o aqui :',
	'texte_login_ldap_1' => '(Deixar vazio para um acesso anónimo, ou introduzir o caminho completo, por exemplo, « <tt>uid=silva, ou=users, dc=meu-dominio, dc=com</tt> ».)',
	'texte_login_precaution' => 'Atenção ! Isto é o login sob o qual está ligado actualmente.
Utilize este formulário com precaução...',
	'texte_messagerie_agenda' => 'Um sistema de mensagens permite aos redactores deste sítio comunicar directamente entre si na área privada. Está associado a uma agenda.',
	'texte_mise_a_niveau_base_1' => 'Acaba de actualizar os ficheiros SPIP.
Agora é preciso pôr a nível a base de dados do sítio. ',
	'texte_modifier_article' => 'Modificar o artigo :',
	'texte_multilinguisme' => 'Se desejar gerir artigos em muitos idiomas, com uma navegação complexa, pode acrescentar um menu de idioma aos artigos e/ou às rubricas, em função da organização do seu sítio.',
	'texte_multilinguisme_trad' => 'Pode também activar um sistema de gestão de ligações entre as diferentes traduções de um artigo.',
	'texte_non_compresse' => '<i>não comprimido</i> ( o seu servidor não suporta esta funcionalidade)',
	'texte_nouvelle_version_spip_1' => 'Instalou uma nova versão de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Esta nova versão precisa de uma actualização mais completa do que o normal. Se é o webmaster do sítio, por favor, apague o ficheiro <tt>inc_connect.php3</tt> do directório <tt>ecrire</tt> e retome a instalação de modo a incluir os seus parâmetros de ligação à base de dados.<p> (NB.: se não se lembra dos seus parâmetros de ligação, consulte o arquivo @connect@ antes de o apagar...)</p>',
	'texte_operation_echec' => 'Volte à página anterior, seleccione uma outra base de dados ou crie uma nova. Verifique as informações fornecidas pelo seu serviço de hospedagem.',
	'texte_plus_trois_car' => 'mais de 3 carácteres',
	'texte_plusieurs_articles' => 'Muitos autores encontrados para "@cherche_auteur@":',
	'texte_port_annuaire' => '(O valor indicado por defeito geralmente convém.)',
	'texte_presente_plugin' => 'Esta página mostra os plugins disponíveis neste sítio. Pode activar os plugins necessários selaccionando a caixa correspondente.',
	'texte_proposer_publication' => 'Quando terminar o seu artigo, <br /> pode propor a sua publicação.',
	'texte_proxy' => 'Em alguns caso (intranet, redes protegidas...),
 pode ser necessário utilizar um <i>proxy HTTP</i>  para atingir os sítios vinculados.
 Se for o caso, indique a seguir o endereço, sob a forma
 @proxy_en_cours@. Em geral,
 poderá deixar esta caixa vazia.',
	'texte_publication_articles_post_dates' => 'Que comportamento SPIP deve adoptar perante os artigos cuja
 data de publicação foi fixada para um prazo futuro ?',
	'texte_rappel_selection_champs' => '[Não esquecer de seleccionar correctamente este campo.]',
	'texte_recalcul_page' => 'Se quiser
recompor uma única página, passe pelo espaço público e utilize o botão «recompor».',
	'texte_recuperer_base' => 'Reparar a base de dados',
	'texte_reference_mais_redirige' => 'artigo referenciado no seu sítio SPIP, mas redirigido para uma outra URL.',
	'texte_requetes_echouent' => '<b>Quando algumas consultas SQL falharem sistematicamente e sem razão aparente, é possível que seja por causa da  própria base de dados
.</b><p>
SQL dispõe de uma funcionalidade de reparação das suas tabelas quando forem acidententalmente danificadas. Pode tentar aqui essa reparação: se falhar, conserve uma cópia da exibição que talvez contenha
indícios daquilo que não funciona...<p>
Se o problema persistir, contacte o seu serviço de hospedagem.',
	'texte_selection_langue_principale' => 'Pode seleccionar a seguir o  « idioma principal » do sítio. Esta opção não o obriga - felizmente ! - a escrever os seus artigos no idioma seleccionado, mas permite determinar :
 <u><li> o formato por defeito das datas no sítio público ;</li>
 <li> a natureza do motor tipográfico que SPIP deve utilizar para a restituição dos textos ;</li>
  <li> o idioma utilizado nos formulários do sítio público ;</li>
  <li> o idioma apresentado por defeito no espaço privado.</li></ul> ',
	'texte_sous_titre' => 'Sub-título',
	'texte_statistiques_visites' => '(barras escuras : domingo / curva escura : evolução da média)',
	'texte_statut_attente_validation' => 'à espera de validação',
	'texte_statut_publies' => 'publicados online',
	'texte_statut_refuses' => 'recusados',
	'texte_suppression_fichiers' => 'Utilize este comando para suprimir todos os ficheiros presentes
na cache SPIP. Isso permite, por exemplo, obrigar uma recomposição de todas as páginas se você
 fez modificações importantes de grafismo ou de estrutura do sítio.',
	'texte_sur_titre' => 'Supra-título',
	'texte_table_ok' => ': esta tabela está OK.',
	'texte_tentative_recuperation' => 'Tentativa de reparação',
	'texte_tenter_reparation' => 'Tentar uma reparação da base de dados',
	'texte_test_proxy' => 'Para experimentar este proxy, indique aqui o endereço de um sítio Web
  que deseje testar;',
	'texte_titre_02' => 'Título',
	'texte_titre_obligatoire' => '<b>Título</b> [Obrigatório]',
	'texte_travail_article' => '@nom_auteur_modif@ trabalhou sobre este artigo há @date_diff@ minutes',
	'texte_travail_collaboratif' => 'Se é frequente muitos redactores
 trabalharem no mesmo artigo, o sistema
 pode exibir os artigos recentemente « abertos »
a fim de evitar as modificações simultâneas.
  Esta opção está desactivada por defeito
  a fim de evitar exibir mensagens de aviso
 intempestivas.',
	'texte_vide' => 'vazio',
	'texte_vider_cache' => 'Esvaziar a cache',
	'titre_admin_tech' => 'Manutenção técnica',
	'titre_admin_vider' => 'Manutenção técnica',
	'titre_ajouter_un_auteur' => 'Adicionar um autor',
	'titre_ajouter_un_mot' => 'Adicionar uma palavra-chave',
	'titre_cadre_afficher_article' => 'Exibir os artigos',
	'titre_cadre_afficher_traductions' => 'Exibir o estado das traduções para estes idiomas:',
	'titre_cadre_ajouter_auteur' => 'ACRESCENTAR UM AUTOR :',
	'titre_cadre_interieur_rubrique' => 'Dentro da rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMERO',
	'titre_cadre_numero_objet' => '@objet@ NÚMERO:',
	'titre_cadre_signature_obligatoire' => '<b>Assinatura</b> [Obrigatória]<br />',
	'titre_config_contenu_notifications' => 'Notificações',
	'titre_config_contenu_prive' => 'Na área privada',
	'titre_config_contenu_public' => 'No sítio público',
	'titre_config_fonctions' => 'Configuração do sítio',
	'titre_config_langage' => 'Configurar o idioma',
	'titre_configuration' => 'Configuração do sítio',
	'titre_configurer_preferences' => 'Configure as suas preferências',
	'titre_configurer_preferences_menus' => 'Definir as suas preferências de menu',
	'titre_conflit_edition' => 'Conflito durante a redacção',
	'titre_connexion_ldap' => 'Opções: <b>Sua ligação LDAP</b>',
	'titre_groupe_mots' => 'GRUPO DE PALAVRAS :',
	'titre_identite_site' => 'Identidade do sítio',
	'titre_langue_article' => 'IDIOMA DO ARTIGO ',
	'titre_langue_rubrique' => 'Idioma da rubrica',
	'titre_langue_trad_article' => 'IDIOMA E TRADUÇÕES DO ARTIGO',
	'titre_les_articles' => 'OS ARTIGOS',
	'titre_messagerie_agenda' => 'Mensagens e agenda',
	'titre_naviguer_dans_le_site' => 'Navegar no sítio',
	'titre_nouvelle_rubrique' => 'Nova rubrica',
	'titre_numero_rubrique' => 'RUBRICA NÚMERO :',
	'titre_page_articles_edit' => 'Modificar : @titre@',
	'titre_page_articles_page' => 'Os artigos',
	'titre_page_articles_tous' => 'Todo o sítio',
	'titre_page_calendrier' => 'Calendário @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuração do sítio',
	'titre_page_delete_all' => 'Supressão total e irreversível',
	'titre_page_recherche' => 'Resultados da pesquisa @recherche@',
	'titre_page_statistiques_referers' => 'Estatísticas (ligações de entrada)',
	'titre_page_upgrade' => 'Reactualização de SPIP',
	'titre_preference_menus_favoris' => 'Menus de marcadores',
	'titre_publication_articles_post_dates' => 'Publicação dos artigos pós-datados',
	'titre_reparation' => 'Reparação',
	'titre_suivi_petition' => 'Seguimento dos abaixo-assinados',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Todas as versões deste artigo :',
	'trad_delier' => 'Não voltar a ligar este artigo a estas traduções',
	'trad_lier' => 'Este artigo é uma tradução do artigo número :',
	'trad_new' => 'Escrever uma nova tradução deste artigo',

	// U
	'utf8_convert_erreur_orig' => 'Erro : o conjunto de caracteres @charset@ não é suportado.',

	// V
	'version' => 'Versão:'
);
